@@ -15,11 +15,10 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-"""Classes for color scheme definitions."""
-
 import nfoview
 
 from nfoview.i18n import _
+from nfoview.i18n import __
 
 __all__ = (
     "BlackOnWhite",
@@ -31,11 +30,8 @@ __all__ = (
     "WhiteOnBlack",
 )
 
-
 class ColorScheme:
 
-    """Baseclass for color scheme definitions."""
-
     name         = NotImplementedError
     label        = NotImplementedError
     foreground   = NotImplementedError
@@ -43,107 +39,90 @@ class ColorScheme:
     link         = NotImplementedError
     visited_link = NotImplementedError
 
-
 class BlackOnWhite(ColorScheme):
 
-    """Color scheme with black text on white background."""
-
     name         = "black-on-white"
-    label        = _("Black on white")
+    label        = __("Black on white")
     foreground   = "#000000"
     background   = "#ffffff"
     link         = "#0000ff"
     visited_link = "#ff00ff"
 
-
 class Custom(ColorScheme):
 
-    """Color scheme with custom, user-chosen colors."""
-
     name         = "custom"
-    label        = _("Custom")
+    label        = __("Custom")
     foreground   = nfoview.conf.foreground_color
     background   = nfoview.conf.background_color
     link         = nfoview.conf.link_color
     visited_link = nfoview.conf.visited_link_color
 
-
 class DarkGreyOnLightGray(ColorScheme):
 
-    """Color scheme with dark grey text on light grey background."""
-
     name         = "dark-grey-on-light-grey"
-    label        = _("Dark grey on light grey")
+    label        = __("Dark grey on light grey")
     foreground   = "#666666"
     background   = "#f2f2f2"
     link         = "#5555ff"
     visited_link = "#ff55ff"
 
-
 class Default(ColorScheme):
 
-    """Color scheme with system default colors."""
-
-    # http://git.gnome.org/browse/gtk+/tree/gtk/theme/Adwaita/_colors-public.scss
-    # http://git.gnome.org/browse/gtk+/tree/gtk/theme/Adwaita/gtk-contained.css
+    # https://github.com/GNOME/gtk/blob/main/gtk/theme/Default/_colors.scss
+    # https://github.com/GNOME/gtk/blob/main/gtk/theme/Default/_colors-public.scss
 
     name         = "default"
-    label        = _("System theme")
+    label        = __("System theme")
     foreground   = nfoview.util.lookup_color("theme_text_color", "#000000")
     background   = nfoview.util.lookup_color("theme_base_color", "#ffffff")
     link         = "#2a76c6"
     visited_link = "#215d9c"
 
-
 class GreyOnBlack(ColorScheme):
 
-    """Color scheme with grey text on black background."""
-
     name         = "grey-on-black"
-    label        = _("Grey on black")
+    label        = __("Grey on black")
     foreground   = "#aaaaaa"
     background   = "#000000"
     link         = "#aaaaff"
     visited_link = "#ffaaff"
 
-
 class LightGreyOnDarkGray(ColorScheme):
 
-    """Color scheme with light grey text on dark grey background."""
-
     name         = "light-grey-on-dark-grey"
-    label        = _("Light grey on dark grey")
+    label        = __("Light grey on dark grey")
     foreground   = "#f2f2f2"
     background   = "#666666"
     link         = "#aaaaff"
     visited_link = "#ffaaff"
 
-
 class WhiteOnBlack(ColorScheme):
 
-    """Color scheme with white text on black background."""
-
     name         = "white-on-black"
-    label        = _("White on black")
+    label        = __("White on black")
     foreground   = "#ffffff"
     background   = "#000000"
     link         = "#aaaaff"
     visited_link = "#ffaaff"
 
+def _ensure_translated():
+    for class_name in __all__:
+        scheme = globals()[class_name]
+        if isinstance(scheme.label, __):
+            scheme.label = _(scheme.label)
 
 def get(name, fallback=None):
-    """Return the color scheme with given name."""
+    _ensure_translated()
     for class_name in __all__:
         scheme = globals()[class_name]
         if scheme.name == name:
             return scheme
     if fallback is not None:
         return get(fallback)
-    raise ValueError("No color scheme named {}"
-                     .format(repr(name)))
+    raise ValueError(f"No color scheme named {name!r}")
 
 def get_all():
-    """Return a list of all color schemes in proper order."""
+    _ensure_translated()
     schemes = list(map(globals().get, __all__))
     schemes.remove(Default)
     schemes.remove(Custom)
