@@ -19,11 +19,11 @@ import nfoview
 
 from gi.repository import Gtk
 
-
 class TestOpenDialog(nfoview.TestCase):
 
     def run_dialog(self):
-        self.dialog.run()
+        self.dialog.show()
+        self.main_loop(self.dialog)
 
     def setup_method(self, method):
         self.dialog = nfoview.OpenDialog(Gtk.Window())
